==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PagedDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LocalDataSourceDescriptionMetadata } from "./LocalDataSourceDescriptionMetadata";
import { PagedDataSourceDescription } from "./PagedDataSourceDescription";
/**
 * @hidden
 */
var PagedDataSourceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PagedDataSourceDescriptionMetadata, _super);
    function PagedDataSourceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PagedDataSourceDescriptionMetadata.b = function (a) {
        if (PagedDataSourceDescriptionMetadata.a == null) {
            PagedDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PagedDataSourceDescriptionMetadata.c(PagedDataSourceDescriptionMetadata.a);
        }
        if (a.g(PagedDataSourceDescriptionMetadata.a)) {
            return;
        }
        a.s(PagedDataSourceDescriptionMetadata.a);
    };
    PagedDataSourceDescriptionMetadata.c = function (a) {
        LocalDataSourceDescriptionMetadata.c(a);
    };
    PagedDataSourceDescriptionMetadata.d = function (a) {
        PagedDataSourceDescriptionMetadata.b(a);
        a.u("PagedDataSource", function () { return new PagedDataSourceDescription(); });
        a.t("PagedDataSource", PagedDataSourceDescriptionMetadata.a);
    };
    PagedDataSourceDescriptionMetadata.$t = markType(PagedDataSourceDescriptionMetadata, 'PagedDataSourceDescriptionMetadata');
    PagedDataSourceDescriptionMetadata.a = null;
    return PagedDataSourceDescriptionMetadata;
}(Base));
export { PagedDataSourceDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PagedDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LocalDataSourceDescriptionMetadata } from "./LocalDataSourceDescriptionMetadata";
import { PagedDataSourceDescription } from "./PagedDataSourceDescription";
/**
 * @hidden
 */
var PagedDataSourceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PagedDataSourceDescriptionMetadata, _super);
    function PagedDataSourceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PagedDataSourceDescriptionMetadata.b = function (a) {
        if (PagedDataSourceDescriptionMetadata.a == null) {
            PagedDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PagedDataSourceDescriptionMetadata.c(PagedDataSourceDescriptionMetadata.a);
        }
        if (a.j(PagedDataSourceDescriptionMetadata.a)) {
            return;
        }
        a.y(PagedDataSourceDescriptionMetadata.a);
    };
    PagedDataSourceDescriptionMetadata.c = function (a) {
        LocalDataSourceDescriptionMetadata.c(a);
    };
    PagedDataSourceDescriptionMetadata.d = function (a) {
        PagedDataSourceDescriptionMetadata.b(a);
        a.aa("PagedDataSource", function () { return new PagedDataSourceDescription(); });
        a.z("PagedDataSource", PagedDataSourceDescriptionMetadata.a);
    };
    PagedDataSourceDescriptionMetadata.$t = markType(PagedDataSourceDescriptionMetadata, 'PagedDataSourceDescriptionMetadata');
    PagedDataSourceDescriptionMetadata.a = null;
    return PagedDataSourceDescriptionMetadata;
}(Base));
export { PagedDataSourceDescriptionMetadata };
